@@ -96,20 +96,21 @@ from fattureincloud_python_sdk.model.create_vat_type_response import (
     CreateVatTypeResponse,
 )
 from fattureincloud_python_sdk.model.currency import Currency
-from fattureincloud_python_sdk.model.default_payment_terms_type import (
-    DefaultPaymentTermsType,
-)
 from fattureincloud_python_sdk.model.detailed_country import DetailedCountry
 from fattureincloud_python_sdk.model.document_template import DocumentTemplate
 from fattureincloud_python_sdk.model.e_invoice_rejection_reason import (
     EInvoiceRejectionReason,
 )
+from fattureincloud_python_sdk.model.email import Email
+from fattureincloud_python_sdk.model.email_attachment import EmailAttachment
 from fattureincloud_python_sdk.model.email_data import EmailData
 from fattureincloud_python_sdk.model.email_data_default_sender_email import (
     EmailDataDefaultSenderEmail,
 )
+from fattureincloud_python_sdk.model.email_recipient_status import EmailRecipientStatus
 from fattureincloud_python_sdk.model.email_schedule import EmailSchedule
 from fattureincloud_python_sdk.model.email_schedule_include import EmailScheduleInclude
+from fattureincloud_python_sdk.model.email_status import EmailStatus
 from fattureincloud_python_sdk.model.entity import Entity
 from fattureincloud_python_sdk.model.entity_type import EntityType
 from fattureincloud_python_sdk.model.f24 import F24
@@ -221,6 +222,9 @@ from fattureincloud_python_sdk.model.issued_document_pre_create_info_items_defau
 from fattureincloud_python_sdk.model.issued_document_status import IssuedDocumentStatus
 from fattureincloud_python_sdk.model.issued_document_totals import IssuedDocumentTotals
 from fattureincloud_python_sdk.model.issued_document_type import IssuedDocumentType
+from fattureincloud_python_sdk.model.join_issued_documents_response import (
+    JoinIssuedDocumentsResponse,
+)
 from fattureincloud_python_sdk.model.language import Language
 from fattureincloud_python_sdk.model.list_archive_categories_response import (
     ListArchiveCategoriesResponse,
@@ -254,6 +258,10 @@ from fattureincloud_python_sdk.model.list_delivery_notes_default_causals_respons
 from fattureincloud_python_sdk.model.list_detailed_countries_response import (
     ListDetailedCountriesResponse,
 )
+from fattureincloud_python_sdk.model.list_emails_response import ListEmailsResponse
+from fattureincloud_python_sdk.model.list_emails_response_page import (
+    ListEmailsResponsePage,
+)
 from fattureincloud_python_sdk.model.list_f24_response import ListF24Response
 from fattureincloud_python_sdk.model.list_f24_response_aggregated_data import (
     ListF24ResponseAggregatedData,
@@ -387,6 +395,7 @@ from fattureincloud_python_sdk.model.payment_account_type import PaymentAccountT
 from fattureincloud_python_sdk.model.payment_method import PaymentMethod
 from fattureincloud_python_sdk.model.payment_method_details import PaymentMethodDetails
 from fattureincloud_python_sdk.model.payment_method_type import PaymentMethodType
+from fattureincloud_python_sdk.model.payment_terms_type import PaymentTermsType
 from fattureincloud_python_sdk.model.permission_level import PermissionLevel
 from fattureincloud_python_sdk.model.permissions import Permissions
 from fattureincloud_python_sdk.model.permissions_fic_issued_documents_detailed import (
@@ -434,6 +443,9 @@ from fattureincloud_python_sdk.model.sender_email import SenderEmail
 from fattureincloud_python_sdk.model.show_totals_mode import ShowTotalsMode
 from fattureincloud_python_sdk.model.supplier import Supplier
 from fattureincloud_python_sdk.model.supplier_type import SupplierType
+from fattureincloud_python_sdk.model.transform_issued_document_response import (
+    TransformIssuedDocumentResponse,
+)
 from fattureincloud_python_sdk.model.upload_archive_attachment_response import (
     UploadArchiveAttachmentResponse,
 )
@@ -458,6 +470,9 @@ from fattureincloud_python_sdk.model.verify_e_invoice_xml_error_response import
 from fattureincloud_python_sdk.model.verify_e_invoice_xml_error_response_error import (
     VerifyEInvoiceXmlErrorResponseError,
 )
+from fattureincloud_python_sdk.model.verify_e_invoice_xml_error_response_error_validation_result import (
+    VerifyEInvoiceXmlErrorResponseErrorValidationResult,
+)
 from fattureincloud_python_sdk.model.verify_e_invoice_xml_error_response_extra import (
     VerifyEInvoiceXmlErrorResponseExtra,
 )
